' ========================================================================================
' GdipGetLineColors
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

%IDC_GRAPHIC = 101

' ========================================================================================
' The following example creates a linear gradient brush and gets the boundary colors.
' Next, the code uses each of the two colors to create a solid brush. Then, the code fills
' a rectangle with each solid brush.
' ========================================================================================
SUB GDIP_GetLineColors (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pLinBrush AS DWORD
   LOCAL colorBlack AS DWORD
   LOCAL colorBlue AS DWORD
   LOCAL pSolidBrush0 AS DWORD
   LOCAL pSolidBrush1 AS DWORD
   LOCAL pt1 AS POINTF
   LOCAL pt2 AS POINTF
   DIM   colors(1) AS DWORD

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create a linear gradient brush.
   pt1.x = 0 : pt1.y = 0 : pt2.x = 100 : pt2.y = 50
   colorBlack = GDIP_ARGB(255, 0, 0, 0)
   colorBlue = GDIP_ARGB(255, 0, 0, 255)
   hStatus = GdipCreateLineBrush(pt1, pt2, colorBlack, colorBlue, %WrapModeTile, pLinBrush)

   ' // Obtain information about the linear gradient brush.
   hStatus = GdipGetLineColors(pLinBrush, colors(0))

   ' // Fill a small rectangle with each of the two colors.
   hStatus = GdipCreateSolidFill(colors(0), pSolidBrush0)
   hStatus = GdipCreateSolidFill(colors(1), pSolidBrush1)

   hStatus = GdipFillRectangle(pGraphics, pSolidBrush0, 0, 0, 20, 20)
   hStatus = GdipFillRectangle(pGraphics, pSolidBrush1, 25, 0, 20, 20)

   ' // Cleanup
   IF pSolidBrush0 THEN hStatus = GdipDeleteBrush(pSolidBrush0)
   IF pSolidBrush1 THEN hStatus = GdipDeleteBrush(pSolidBrush1)
   IF pLinBrush THEN GdipDeleteBrush(pLinBrush)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL hdc AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   ' Create a new dialog
   DIALOG NEW PIXELS, 0, "GdipGetLineColors", , , 400, 250, %WS_SYSMENU TO hDlg

   ' Add a graphic control
   CONTROL ADD GRAPHIC, hDlg, %IDC_GRAPHIC,"", 0, 0, 400, 250
   ' Select the drawing target
   GRAPHIC ATTACH hDlg, %IDC_GRAPHIC
   ' Set the foreground and background color
   GRAPHIC COLOR %BLACK, %WHITE
   ' Clear the entire selected graphic window
   GRAPHIC CLEAR
   ' Retrieve the handle of the device context
   GRAPHIC GET DC TO hdc
   ' Draw the graphics
   GDIP_GetLineColors hdc

   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' ========================================================================================
